package com.xty.common.util

import android.os.Build
import androidx.annotation.RequiresApi
import com.xty.common.Const
import com.xty.network.model.SettingBean
import java.text.SimpleDateFormat
import java.time.LocalDate
import java.time.format.DateTimeFormatter
import java.util.Calendar
import java.util.Locale

/**
 * 通用信息封装
 */
object CommonUtils {

    fun isBlueTooth(watchType: Int): Boolean{
        return Const.Companion.WatchDevice.BlueU32.ordinal == watchType
    }

    /**
     * 获取用户蓝牙地址信息
     */
    fun getBlueToothMac(id: String = ""): String? {
        val myUserId = getMyUserId()
        if (id.isNullOrEmpty() || myUserId == id) {  //为空或者和本地保存的一致则认为是本人
            return getMyUserInfo()?.bluetooth
        } else {//这里应该要拿家人用户的蓝牙信息

        }
        return null
    }

    /**
     * 获取用户设备id
     */
    fun getDeviceId(id: String = ""): String? {
        val myUserId = getMyUserId()
        if (id.isNullOrEmpty() || myUserId == id) {  //为空或者和本地保存的一致则认为是本人
            return getMyUserInfo()?.deviceId
        } else {//这里应该要拿家人用户的蓝牙信息

        }
        return null
    }

    /**
     * 获取用户id
     */
    fun getMyUserId(): String?{
        var myUserId = ""
        getMyUserInfo()?.apply {
            myUserId = id.toString()
        }
        return  myUserId
    }

    /**
     * 获取用户管家ID
     */
    fun getMyAdminId(): String?{
        var myAdminId = ""
        getMyUserInfo()?.apply {
            myAdminId = userId.toString()
        }
        return  myAdminId
    }

    /**
     * 获取个人用户信息
     */
    fun getMyUserInfo(): SettingBean.User?{
        return getMySettingInfo()?.user
    }

    /**
     * 获取个人设置信息
     */
    fun getMySettingInfo(): SettingBean?{
        return Const.mainLiveData?.value
    }

    fun getSpaceTime(dayNum:Int) :String {
        // 获取当前时间
        val currentTime = Calendar.getInstance()

        // 计算七天前的时间
        val sevenDaysAgo = Calendar.getInstance()
        sevenDaysAgo.add(Calendar.DAY_OF_YEAR, -dayNum)

        // 定义日期格式
        val dateFormat = SimpleDateFormat("yyyy-MM-dd", Locale.getDefault())

        // 格式化日期为字符串
        val currentDateStr = dateFormat.format(currentTime.time)
        val sevenDaysAgoStr = dateFormat.format(sevenDaysAgo.time)


        return "${sevenDaysAgoStr}至${currentDateStr}"
    }

    fun getSpaceTimeOneDay() :String {
        // 获取当前时间
        val currentTime = Calendar.getInstance()

        // 计算七天前的时间
        val sevenDaysAgo = Calendar.getInstance()
        sevenDaysAgo.add(Calendar.DAY_OF_YEAR, -1)

        // 定义日期格式
        val dateFormat = SimpleDateFormat("MM-dd HH:mm", Locale.getDefault())

        // 格式化日期为字符串
        val currentDateStr = dateFormat.format(currentTime.time)
        val sevenDaysAgoStr = dateFormat.format(sevenDaysAgo.time)


        return "${sevenDaysAgoStr}至${currentDateStr}"
    }

    fun stringToDoubleOne(date :String):String{
        return "%.1f".format(date.toFloat())
    }

     fun replaceMiddleNumber(str:String):String{
        val middleNum = str.substring(3,7)
        val newMiddleNum = middleNum.replace(middleNum,"****")
        val replaceNum = str.substring(0,3)+newMiddleNum + str.substring(7,str.length)
        return replaceNum
    }

}